@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Get XML.
 has xml => (
@@ -129,7 +129,6 @@ For more information about Warsaw Map, click L<here|https://en.wikipedia.org/wik
 
  # Pragmas.
  use strict;
- use utf8;
  use warnings;
 
  # Modules.
@@ -164,7 +163,6 @@ For more information about Warsaw Map, click L<here|https://en.wikipedia.org/wik
  # GraphViz object.
  my $g = Map::Tube::GraphViz->new(
          'callback_node' => \&node_color_without_label,
-         'driver' => 'neato',
          'tube' => $obj,
  );
 
@@ -175,7 +173,7 @@ For more information about Warsaw Map, click L<here|https://en.wikipedia.org/wik
  system "ls -l Warsaw.png";
 
  # Output like:
- # -rw-r--r-- 1 skim skim 71382 Dec 28 19:58 Warsaw.png
+ # -rw-r--r-- 1 skim skim 86520 Mar 13 05:03 Warsaw.png
 
 =begin html
 
@@ -195,26 +193,37 @@ L<namespace::clean>.
 =head1 SEE ALSO
 
 L<Map::Tube>,
+L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
+L<Map::Tube::Plugin::FuzzyFind>,
+L<Map::Tube::Plugin::Graph>,
+L<Map::Tube::Text::Shortest>,
 L<Map::Tube::Text::Table>,
 L<Task::Map::Tube>.
 
 L<Map::Tube::Barcelona>,
+L<Map::Tube::Beijing>,
 L<Map::Tube::Berlin>,
 L<Map::Tube::Bucharest>,
+L<Map::Tube::Budapest>,
 L<Map::Tube::Delhi>,
 L<Map::Tube::Dnipropetrovsk>,
+L<Map::Tube::Glasgow>,
 L<Map::Tube::Kazan>,
 L<Map::Tube::Kharkiv>,
 L<Map::Tube::Kiev>,
+L<Map::Tube::KoelnBonn>,
 L<Map::Tube::London>,
+L<Map::Tube::Lyon>,
 L<Map::Tube::Minsk>,
 L<Map::Tube::Moscow>,
-L<Map::Tube::Novosibirsk>,
 L<Map::Tube::NYC>,
+L<Map::Tube::Nanjing>,
+L<Map::Tube::Novosibirsk>,
 L<Map::Tube::Prague>,
 L<Map::Tube::SaintPetersburg>,
 L<Map::Tube::Samara>,
+L<Map::Tube::Singapore>,
 L<Map::Tube::Sofia>,
 L<Map::Tube::Tbilisi>,
 L<Map::Tube::Tokyo>,
@@ -233,12 +242,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © Michal Špaček 2014
+ © 2014-2015 Michal Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
